
// Create notification actions
var acceptAction = Ti.App.iOS.createUserNotificationAction({
    identifier: "ACCEPT_IDENTIFIER",
    title: "Accept",
    activationMode: Ti.App.iOS.USER_NOTIFICATION_ACTIVATION_MODE_FOREGROUND,
    destructive: false,
    authenticationRequired: true
});

var rejectAction = Ti.App.iOS.createUserNotificationAction({
    identifier: "REJECT_IDENTIFIER",
    title: "Reject",
    activationMode: Ti.App.iOS.USER_NOTIFICATION_ACTIVATION_MODE_BACKGROUND,
    destructive: true,
    authenticationRequired: false
});

// Create a notification category
var downloadContent = Ti.App.iOS.createUserNotificationCategory({
  identifier: "DOWNLOAD_CONTENT",
  actionsForDefaultContext: [acceptAction, rejectAction]
});    

// Monitor notifications received while app is in the background
Ti.App.iOS.addEventListener('remotenotificationaction', function(e) {
    if (e.category == "DOWNLOAD_CONTENT" && e.identifier == "ACCEPT_IDENTIFIER") {
        Ti.API.warn("start download");
    }
    
    // Reset the badge value
    if (e.badge > 0) {
        Ti.App.iOS.scheduleLocalNotification({
            date: new Date(new Date().getTime() + 3000),
            badge: "-1"
        });
    }
    Ti.API.warn(e);
    Ti.API.warn("event: remotenotificationaction");
});

// Monitor notifications received while app is in the foreground 
Ti.App.iOS.addEventListener('notification', function(e) { 
    Ti.API.warn("event: notification");
});

function deviceTokenSuccess(e) {
    Ti.API.warn("successfully registered for remote notifications!");
    alert(e);
    Ti.API.warn(e);
}

function deviceTokenError(e) {
    Ti.API.warn("error while registering for remote notifications!");
    Ti.API.error(e);
}

function receivePush(e) {
    Ti.API.warn("received remote push notification!");
    Ti.API.warn(e);
}

function registerForPush() {
   Ti.Network.registerForPushNotifications({
       success: deviceTokenSuccess,
       error: deviceTokenError,
       callback: receivePush
   });
   // Remove event listener once registered for push notifications
   Ti.App.iOS.removeEventListener('usernotificationsettings', registerForPush); 
};
 
// Wait for user settings to be registered before registering for push notifications
Ti.App.iOS.addEventListener('usernotificationsettings', registerForPush);

// App UI
var win = Ti.UI.createWindow({backgroundColor: 'white'});
var button = Ti.UI.createButton({title: 'Register for Remote Push Notifications'});

button.addEventListener('click', function(e){ 
    // Register for user notifications and categories
    Ti.API.info("Register for user notifications and categories");
    Ti.App.iOS.registerUserNotificationSettings({
        types: [
            Ti.App.iOS.USER_NOTIFICATION_TYPE_ALERT,
            Ti.App.iOS.USER_NOTIFICATION_TYPE_BADGE,
            Ti.App.iOS.USER_NOTIFICATION_TYPE_SOUND
        ],
        categories: [downloadContent]
    });  
});

win.add(button);
win.open();
